<h1 align="center">Arabic Text Normalization</h1>



### What is Arabic Text Normalization?
It is a python library that contains aclass to normalize arabic text 

### Support
+ linux
+ Windows

### Install
Just write this code on terminal:
```shell
pip install ArabicNormalization
```

 
<p align="center">
<strong>For more infrmation</strong>
</p>


___
